
#line 3 "lex.yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 31
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined __STDC_VERSION__ && __STDC_VERSION__ >= 199901L
#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else   /* ! __cplusplus */

#if __STDC__

#define YY_USE_CONST

#endif  /* __STDC__ */
#endif  /* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
        do \
                { \
                /* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
                *yy_cp = (yy_hold_char); \
                YY_RESTORE_YY_MORE_OFFSET \
                (yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
                YY_DO_BEFORE_ACTION; /* set up yytext again */ \
                } \
        while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

/* The following is because we cannot portably get our hands on size_t
 * (without autoconf's help, which isn't available because we want
 * flex-generated scanners to compile on their own).
 */

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef unsigned int yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
        {
        FILE *yy_input_file;

        char *yy_ch_buf;                /* input buffer */
        char *yy_buf_pos;               /* current position in input buffer */

        /* Size of input buffer in bytes, not including room for EOB
         * characters.
         */
        yy_size_t yy_buf_size;

        /* Number of characters read into yy_ch_buf, not including EOB
         * characters.
         */
        int yy_n_chars;

        /* Whether we "own" the buffer - i.e., we know we created it,
         * and can realloc() it to grow it, and should free() it to
         * delete it.
         */
        int yy_is_our_buffer;

        /* Whether this is an "interactive" input source; if so, and
         * if we're using stdio for input, then we want to use getc()
         * instead of fread(), to make sure we stop fetching input after
         * each newline.
         */
        int yy_is_interactive;

        /* Whether we're considered to be at the beginning of a line.
         * If so, '^' rules will be active on the next match, otherwise
         * not.
         */
        int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
        /* Whether to try to fill the input buffer when we reach the
         * end of it.
         */
        int yy_fill_buffer;

        int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
        /* When an EOF's been seen but there's still some text to process
         * then we mark the buffer as YY_EOF_PENDING, to indicate that we
         * shouldn't try reading from the input source any more.  We might
         * still have a bunch of tokens to match, though, because of
         * possible backing-up.
         *
         * When we actually see the EOF, we change the status to "new"
         * (via yyrestart()), so that the user can continue scanning by
         * just pointing yyin at a new input file.
         */
#define YY_BUFFER_EOF_PENDING 2

        };
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;          /* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 1;         /* whether we need to initialize */
static int yy_start = 0;        /* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
        { \
        if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
                YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
        } \
        YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
        }

#define yy_set_bol(at_bol) \
        { \
        if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
                YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
        } \
        YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
        }

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
        (yytext_ptr) = yy_bp; \
        yyleng = (size_t) (yy_cp - yy_bp); \
        (yy_hold_char) = *yy_cp; \
        *yy_cp = '\0'; \
        (yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 74
#define YY_END_OF_BUFFER 75
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
        {
        flex_int32_t yy_verify;
        flex_int32_t yy_nxt;
        };
static yyconst flex_int16_t yy_accept[629] =
    {   0,
        0,    0,   75,   73,   69,   69,   73,   72,   73,   64,
       68,   68,   70,   71,   68,   68,   68,   68,   68,   68,
       68,   68,   68,   68,   69,    9,    9,   73,   73,    0,
        1,   11,   64,   68,   68,    0,    0,   68,   68,   68,
       68,   68,   68,   68,   68,   68,   68,   68,   68,   68,
       68,   68,   68,   68,    0,    9,    0,    0,   66,   10,
       65,   11,   68,    0,    0,   14,   68,   68,   68,   68,
       68,   68,   25,   68,   68,   68,   68,   68,   68,   68,
       68,   68,   68,   67,   10,   10,   10,   10,   68,   31,
       68,   68,   68,   68,   68,    0,   68,   68,   28,   68,

       68,   68,   68,   68,   68,   68,   68,   30,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   10,   10,
       10,   10,   10,   10,   68,   68,   68,   21,   33,   68,
       26,   68,    0,    0,   68,   68,    0,   68,   68,   68,
       68,   68,   27,   68,   68,   68,    0,    0,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   10,   10,   10,
       10,   10,   10,   10,   68,   68,    0,   29,   36,    0,
        0,   68,   68,    0,   68,   68,   68,   68,   22,    0,
       68,   37,   68,   68,    0,    0,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   10,   10,   10,   10,   10,

       10,   10,   10,    2,   68,   68,    0,    0,    0,    0,
       20,   68,    0,   18,   68,   23,   68,    0,   68,   68,
       32,    0,    0,    0,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   10,   10,   10,   10,   10,   10,   10,   68,   68,
        0,   20,    0,   19,   18,   34,   68,    0,   17,   35,
        0,    0,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       10,   10,   10,    3,   10,   10,   68,   68,    0,   19,
       24,   17,    0,    0,   67,   67,   67,   67,   67,   67,

       39,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,    3,   10,   10,    3,   10,   10,   12,   63,
        0,    0,   15,    0,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,    3,   10,   10,   10,   10,    0,   67,   67,   41,
       67,   67,   67,    0,    0,   67,   40,   67,   67,   67,
       67,   67,   67,   67,   67,   10,   10,   10,   10,    0,
       67,   67,   67,   67,   67,    0,   13,   67,   67,   67,
       67,   67,   61,   67,   67,   67,   10,   10,   10,   10,
        0,    0,   67,   67,   67,   67,   67,   67,   67,   67,

       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   10,   10,   10,   10,   10,   10,   10,
        0,   16,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   10,   10,   10,   10,   10,   10,   10,
       10,   10,   10,   48,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   10,   10,   10,   10,   10,   10,
       10,   10,   10,    8,   67,   67,   67,   67,   67,   67,
       67,   67,   44,   67,   67,   67,   67,   67,   67,   67,

       67,   67,   67,   67,   10,   10,   10,   10,    8,   10,
       10,   10,   10,    8,   67,   47,   43,   67,   67,   67,
       67,   58,   45,   67,   42,   67,   67,   67,   67,   57,
       67,   67,   67,   10,   10,   10,   10,    8,   10,   10,
       10,   10,   67,   53,   54,   55,   56,   67,   49,   50,
       51,   52,   67,   67,   67,   10,   10,   10,   10,   10,
       10,   10,   10,   67,   67,   67,   67,   67,   10,   10,
       10,   10,    7,   10,   10,   10,   38,   67,   62,   67,
       67,    7,   10,   10,   10,    7,   10,    5,    6,   67,
       67,   67,    7,   10,    5,    6,   10,    5,    6,   67,

       67,   67,   10,    5,    6,   10,   67,   67,   60,   10,
        4,   67,   67,    4,    4,   67,   67,    4,   67,   59,
       67,   67,   67,   67,   67,   67,   46,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    1,    6,    7,    1,    1,    8,    1,    9,
       10,   11,    1,    8,    8,   12,   13,   14,   15,   16,
       17,   18,   15,   19,   15,   15,   15,   20,   21,    1,
        8,    1,    1,    1,   22,   23,   24,   25,   26,   27,
       28,   29,   30,   29,   31,   32,   33,   34,   35,   36,
       29,   37,   38,   39,   40,   41,   42,   43,   44,   29,
       45,    1,   46,    1,   47,    1,   48,   49,   50,   51,

       52,   53,   54,   55,   56,   57,   58,   59,   60,   61,
       62,   63,   29,   64,   65,   66,   67,   68,   69,   29,
       70,   29,    8,    1,    8,    8,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[71] =
    {   0,
        1,    2,    3,    2,    2,    4,    1,    1,    1,    5,
        1,    1,    1,    6,    6,    6,    6,    6,    6,    1,
        7,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    1,    1,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6
    } ;

static yyconst flex_int16_t yy_base[654] =
    {   0,
        0,   69,  954,  955,  955,  955,    0,  955,   64,   69,
        0,  914,   76,  955,   41,  890,   38,  890,  888,  886,
       34,   44,  887,   49,  104,  955,  955,  944,  101,  940,
      955,    0,  104,    0,  914,  122,  140,  896,  895,  881,
      874,  878,  883,  872,  876,  884,   72,  886,  872,  885,
      867,  867,  874,  871,  147,  955,  915,  924,  955,  108,
      955,    0,  879,  159,    0,  955,  861,  859,  858,  873,
      873,  868,  163,  865,  854,  849,  850,  856,  850,  847,
      856,  845,  859,  146,  124,    0,  121,  870,  104,    0,
      843,  841,  847,  839,  843,  187,  841,  847,  191,  853,

      852,  847,  842,  831,  840,  841,  827,  195,    0,  831,
      833,  839,  839,  827,  836,  817,  830,  823,    0,  123,
      845,  137,  831,  839,  855,  127,  854,  874,    0,  826,
        0,  826,  814,  820,  813,  811,  204,  811,  805,  804,
      819,  818,  208,  817,  805,  817,  212,  221,  802,  801,
      796,  822,  794,  793,  795,  805,  792,  143,  803,  811,
      831,  826,  786,  847,  146,  175,  231,    0,    0,  788,
      786,  793,  782,  784,  778,  781,  790,  775,    0,  235,
      779,    0,  787,  779,  239,  251,  778,  788,  224,  765,
      794,  234,  781,  763,  772,  808,  803,  763,  824,  793,

      801,  774,  820,  955,  194,  157,  274,  756,  767,  756,
        0,  753,  752,    0,  753,    0,  764,  754,  748,  762,
        0,  278,  291,  282,  760,  745,  762,  760,  742,  755,
      743,  740,  745,  755,  753,  749,  734,  747,  194,  735,
      746,  763,  771,  744,  790,  766,  752,  726,  193,  225,
      731,  955,  722,    0,  955,    0,  736,  720,    0,    0,
      299,  307,  737,  728,  733,  725,  717,  730,  727,  726,
      729,  726,  718,  721,  709,  722,  723,  718,  707,  744,
      741,  727,  701,    0,  734,  707,  279,  219,  311,  955,
        0,  955,  317,  700,  700,  699,  695,  706,  701,  690,

        0,  704,  694,  689,  700,  699,  694,  683,  698,  679,
      682,  683,    0,  714,  687,    0,  707,  678,  714,  713,
      322,  326,  955,  682,  704,  682,  673,  684,  672,  670,
      261,  668,  668,  679,  664,  666,  664,  661,  668,  657,
      660,    0,  686,  657,  685,  652,  666,  668,  679,    0,
      648,  659,  648,  328,  701,  677,    0,  643,  656,  653,
      642,  643,  639,  679,  638,  667,  634,  694,  642,  346,
      647,  634,  662,  661,  322,  683,  955,  644,  658,  629,
      656,  343,    0,  632,  625,  635,  680,  628,  328,  621,
      366,  362,  618,  625,  632,  631,  645,  644,  643,  642,

      626,  623,  624,  621,  622,  636,  635,  634,  633,  617,
      602,  601,  606,  349,  599,  612,  607,  606,  605,  595,
      376,  955,  593,  593,  603,  602,  603,  602,  601,  600,
      597,  582,  595,  592,  593,  594,  593,  592,  591,  588,
      576,  572,  574,  586,  581,  580,  579,  569,  561,  563,
      575,  574,  605,    0,  558,  559,  558,  571,  570,  569,
      568,  553,  554,  551,  590,  549,  562,  561,  560,  559,
      544,  574,  555,  557,  536,  538,  550,  549,  580,  547,
      548,  592,  591,    0,  556,  532,  531,  528,  527,  526,
      525,  526,    0,  525,  524,  523,  520,  519,  518,  517,

      518,  531,  522,  511,  524,  525,  569,  568,    0,  524,
      507,  548,  521,    0,  498,    0,    0,  505,  504,  499,
      492,    0,    0,  480,    0,  478,  471,  464,  457,    0,
      462,  444,  446,  436,  415,  456,  423,    0,  393,  389,
      379,  372,  355,    0,    0,    0,    0,  352,    0,    0,
        0,    0,  348,  363,  377,  343,  352,  348,  347,  340,
      341,  338,  337,  349,  334,  337,  332,  349,  331,  332,
      329,  327,    0,  325,  328,  327,    0,  336,    0,  332,
      333,    0,  316,  318,  301,    0,  302,    0,    0,  305,
      321,  282,    0,  289,    0,    0,  282,    0,    0,  301,

      287,  272,  261,    0,    0,  256,  258,  256,    0,  237,
        0,  240,  226,    0,    0,  237,  212,    0,  223,    0,
      202,  215,  154,  128,   68,   54,    0,  955,  414,   98,
      421,  428,  435,   84,  442,   83,  449,  455,  461,  468,
      474,  481,  488,  495,  502,  509,  516,  523,  530,  537,
      544,  551,  558
    } ;

static yyconst flex_int16_t yy_def[654] =
    {   0,
      628,    1,  628,  628,  628,  628,  629,  628,  628,  628,
      630,  630,  628,  628,  630,  630,  630,  630,  630,  630,
      630,  630,  630,  630,  628,  628,  628,  631,  628,  629,
      628,  632,  628,  630,  630,  628,  628,  630,  630,  630,
      630,  630,  630,  630,  630,  630,  630,  630,  630,  630,
      630,  630,  630,  630,  628,  628,  628,  631,  628,  633,
      628,  632,  630,  628,   37,  628,  630,  630,  630,  630,
      630,  630,  630,  630,  630,  630,  630,  630,  630,  630,
      630,  630,  630,  634,  635,  633,  633,  633,  636,  630,
      630,  630,  630,  630,  630,  628,  630,  630,  630,  630,

      630,  630,  630,  630,  630,  630,  630,  630,  634,  634,
      634,  634,  634,  634,  634,  634,  634,  634,  635,  635,
      635,  633,  633,  633,  636,  636,  636,  630,  630,  630,
      630,  630,  628,  628,  630,  630,  628,  630,  630,  630,
      630,  630,  630,  630,  630,  630,  628,  628,  634,  634,
      634,  634,  634,  634,  634,  634,  634,  635,  635,  635,
      633,  633,  633,  637,  636,  636,  628,  630,  630,  628,
      628,  630,  630,  628,  630,  630,  630,  630,  630,  628,
      630,  630,  630,  630,  628,  638,  634,  634,  634,  634,
      634,  634,  634,  634,  634,  635,  635,  635,  639,  633,

      633,  633,  637,  628,  636,  636,  628,  628,  628,  628,
      630,  630,  628,  630,  630,  630,  630,  628,  630,  630,
      630,  628,  628,  638,  634,  634,  634,  634,  634,  634,
      634,  634,  634,  634,  634,  634,  634,  634,  634,  634,
      634,  635,  635,  635,  639,  633,  633,  633,  636,  636,
      628,  628,  628,  630,  628,  630,  630,  628,  630,  630,
      628,  628,  634,  634,  634,  634,  634,  634,  634,  634,
      634,  634,  634,  634,  634,  634,  634,  634,  634,  634,
      635,  635,  635,  640,  633,  633,  636,  636,  641,  628,
      630,  628,  628,  628,  634,  634,  634,  634,  634,  634,

      634,  634,  634,  634,  634,  634,  634,  634,  634,  634,
      634,  634,  642,  635,  635,  640,  633,  633,  636,  636,
      628,  641,  628,  628,  634,  634,  634,  634,  634,  634,
      634,  634,  634,  634,  634,  634,  634,  634,  634,  634,
      634,  642,  635,  635,  633,  633,  628,  634,  634,  634,
      634,  634,  634,  628,  643,  634,  634,  634,  634,  634,
      634,  634,  634,  634,  634,  635,  635,  633,  633,  628,
      634,  634,  634,  634,  634,  643,  628,  634,  634,  634,
      634,  634,  634,  634,  634,  634,  635,  635,  633,  633,
      628,  628,  634,  634,  634,  634,  634,  634,  634,  634,

      634,  634,  634,  634,  634,  634,  634,  634,  634,  634,
      634,  634,  634,  635,  635,  633,  633,  633,  633,  633,
      628,  628,  634,  634,  634,  634,  634,  634,  634,  634,
      634,  634,  634,  634,  634,  634,  634,  634,  634,  634,
      634,  634,  634,  635,  635,  635,  635,  635,  633,  633,
      633,  633,  633,  634,  634,  634,  634,  634,  634,  634,
      634,  634,  634,  634,  634,  634,  634,  634,  634,  634,
      634,  634,  634,  634,  635,  635,  635,  635,  635,  633,
      633,  633,  633,  644,  634,  634,  634,  634,  634,  634,
      634,  634,  634,  634,  634,  634,  634,  634,  634,  634,

      634,  634,  634,  634,  635,  635,  635,  635,  645,  633,
      633,  633,  633,  644,  634,  634,  634,  634,  634,  634,
      634,  634,  634,  634,  634,  634,  634,  634,  634,  634,
      634,  634,  634,  635,  635,  635,  635,  645,  633,  633,
      633,  633,  634,  634,  634,  634,  634,  634,  634,  634,
      634,  634,  634,  634,  634,  635,  635,  635,  635,  633,
      633,  633,  633,  634,  634,  634,  634,  634,  635,  635,
      635,  635,  646,  633,  633,  633,  634,  634,  634,  634,
      634,  647,  635,  635,  635,  646,  633,  648,  649,  634,
      634,  634,  647,  635,  650,  651,  633,  648,  649,  634,

      634,  634,  635,  650,  651,  633,  634,  634,  634,  635,
      652,  634,  634,  653,  652,  634,  634,  653,  634,  634,
      634,  634,  634,  634,  634,  634,  634,    0,  628,  628,
      628,  628,  628,  628,  628,  628,  628,  628,  628,  628,
      628,  628,  628,  628,  628,  628,  628,  628,  628,  628,
      628,  628,  628
    } ;

static yyconst flex_int16_t yy_nxt[1026] =
    {   0,
        4,    5,    6,    5,    5,    7,    4,    8,    8,    8,
        8,    8,    9,   10,   10,   10,   10,   10,   10,    8,
        8,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       12,   11,   11,   11,   13,   14,   11,   11,   11,   15,
       16,   11,   17,   11,   11,   18,   11,   11,   19,   11,
       11,   20,   21,   11,   22,   11,   23,   24,   11,   11,
       25,   26,   27,   25,   31,   28,   32,   36,   36,   36,
       36,   29,   33,   33,   33,   33,   33,   33,  125,  109,
       37,   37,   37,   37,   37,   38,   42,   47,   49,   39,

       48,   43,   40,   34,   52,   55,   56,   56,   55,   50,
       53,   31,   87,   60,   54,  627,   57,   33,   33,   33,
       33,   33,   33,   36,   36,   36,   36,   76,  120,  126,
       88,  626,  122,   77,  158,  127,   37,   37,   37,   37,
       37,   64,   64,   64,   64,  123,  121,  159,   55,   56,
       56,   55,  126,   65,   65,   65,   65,   65,   65,   57,
       64,   64,   64,   64,   96,   96,   96,   96,  110,  165,
      161,  126,  111,  112,  162,  113,  196,  625,  250,  114,
      197,  205,  126,  115,  116,   66,  117,  118,   96,   96,
       96,   96,  137,  137,  137,  137,  147,  147,  147,  147,

      126,  624,  206,  148,   66,  137,  137,  137,  137,  180,
      180,  180,  180,  147,  147,  147,  147,  165,  126,  126,
      148,   97,  185,  185,  185,  185,  277,   98,  249,  287,
      278,  186,  207,  207,  207,  207,  180,  180,  180,  180,
      185,  185,  185,  185,  126,  133,  138,  623,  288,  186,
      126,  134,  222,  222,  222,  222,  227,  233,  228,  174,
      223,  229,  320,  181,  230,  354,  234,  622,  235,  355,
      236,  237,  621,  620,  238,  207,  207,  207,  207,  222,
      222,  222,  222,  222,  222,  222,  222,  223,  619,  617,
      218,  223,  261,  261,  261,  261,  616,  614,  208,  262,

      261,  261,  261,  261,  126,  613,  612,  262,  293,  293,
      293,  293,  321,  321,  321,  321,  611,  319,  293,  293,
      293,  293,  610,  321,  321,  321,  321,  321,  321,  321,
      321,  323,  354,  609,  608,  607,  355,  397,  398,  399,
      400,  208,  323,  606,  603,  602,  323,  391,  391,  391,
      391,  416,  417,  601,  401,  600,  392,  597,  406,  407,
      408,  409,  596,  421,  421,  418,  421,  391,  391,  391,
      391,  422,  444,  445,  294,  410,  392,  421,  421,  595,
      421,  594,  592,  591,  294,  422,  446,  590,  589,  588,
      587,  585,  419,  584,  583,  582,  581,  580,  579,  578,

      577,  576,  575,  574,  573,  572,  571,  570,  569,  568,
      567,  566,  565,  447,   30,   30,   30,  564,   30,   30,
       30,   58,   58,   58,   58,   58,   58,   58,   62,   62,
      563,   62,   62,   62,   62,   86,   86,  562,   86,   86,
       86,   86,  119,  119,  561,  119,  119,  119,  119,  203,
      203,  203,  203,  203,  203,  203,  224,  224,  560,  224,
      224,  245,  245,  245,  245,  245,  245,  245,  316,  316,
      559,  316,  316,  316,  316,  322,  322,  558,  557,  322,
      322,  342,  342,  556,  342,  342,  342,  342,  376,  376,
      376,  376,  376,  376,  376,  514,  514,  555,  514,  514,

      514,  514,  538,  538,  554,  538,  538,  538,  538,  586,
      586,  553,  586,  586,  586,  586,  593,  593,  552,  593,
      593,  593,  593,  598,  598,  551,  598,  598,  598,  598,
      599,  599,  550,  599,  599,  599,  599,  604,  604,  549,
      604,  604,  604,  604,  605,  605,  548,  605,  605,  605,
      605,  615,  615,  547,  615,  615,  615,  615,  618,  618,
      546,  618,  618,  618,  618,  545,  544,  543,  542,  541,
      540,  539,  537,  536,  535,  534,  533,  532,  531,  530,
      529,  528,  527,  526,  525,  524,  523,  522,  521,  520,
      519,  518,  517,  516,  515,  513,  512,  511,  510,  509,

      508,  507,  506,  505,  504,  503,  502,  501,  500,  499,
      498,  497,  496,  495,  494,  493,  492,  491,  490,  489,
      488,  487,  486,  485,  484,  483,  482,  481,  480,  479,
      478,  477,  476,  475,  474,  473,  472,  471,  470,  469,
      468,  467,  466,  465,  464,  463,  462,  461,  460,  459,
      458,  457,  456,  455,  454,  453,  452,  451,  450,  449,
      448,  443,  442,  441,  440,  439,  438,  437,  436,  435,
      434,  433,  432,  431,  430,  429,  428,  427,  426,  425,
      424,  423,  420,  415,  414,  413,  412,  411,  405,  404,
      403,  402,  377,  396,  395,  394,  393,  390,  389,  388,

      387,  386,  385,  384,  383,  382,  381,  380,  379,  378,
      377,  375,  374,  373,  372,  371,  370,  369,  368,  367,
      366,  365,  364,  363,  362,  361,  360,  359,  358,  357,
      356,  353,  352,  351,  350,  349,  348,  347,  126,  126,
      346,  345,  344,  343,  341,  340,  339,  338,  337,  336,
      335,  334,  333,  332,  331,  330,  329,  328,  327,  326,
      325,  324,  318,  317,  315,  314,  313,  312,  311,  310,
      309,  308,  307,  306,  305,  304,  303,  302,  301,  300,
      299,  298,  297,  296,  295,  292,  291,  290,  289,  286,
      285,  284,  204,  283,  282,  281,  280,  279,  276,  275,

      274,  273,  272,  271,  270,  269,  268,  267,  266,  265,
      264,  263,  260,  259,  258,  257,  256,  255,  254,  253,
      252,  251,  204,  248,  247,  246,  204,  244,  243,  242,
      241,  240,  239,  232,  231,  226,  225,  221,  220,  219,
      217,  216,  215,  214,  213,  212,  211,  210,  209,  204,
      202,  201,  200,  199,  198,  195,  194,  193,  192,  191,
      190,  189,  188,  187,  184,  183,  182,  179,  178,  177,
      176,  175,  173,  172,  171,  170,  169,  168,  167,  166,
      126,  164,  163,  160,  157,  156,  155,  154,  153,  152,
      151,  150,  149,  146,  145,  144,  143,  142,  141,  140,

      139,  136,  135,  132,  131,  130,  129,  128,  124,  108,
      107,  106,  105,  104,  103,  102,  101,  100,   99,   95,
       94,   93,   92,   91,   90,   89,   59,   85,   84,   83,
       82,   81,   80,   79,   78,   75,   74,   73,   72,   71,
       70,   69,   68,   67,   63,   61,   59,   51,   46,   45,
       44,   41,   35,  628,    3,  628,  628,  628,  628,  628,
      628,  628,  628,  628,  628,  628,  628,  628,  628,  628,
      628,  628,  628,  628,  628,  628,  628,  628,  628,  628,
      628,  628,  628,  628,  628,  628,  628,  628,  628,  628,
      628,  628,  628,  628,  628,  628,  628,  628,  628,  628,

      628,  628,  628,  628,  628,  628,  628,  628,  628,  628,
      628,  628,  628,  628,  628,  628,  628,  628,  628,  628,
      628,  628,  628,  628,  628
    } ;

static yyconst flex_int16_t yy_chk[1026] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        2,    2,    2,    2,    9,    2,    9,   13,   13,   13,
       13,    2,   10,   10,   10,   10,   10,   10,  636,  634,
       13,   13,   13,   13,   13,   15,   17,   21,   22,   15,

       21,   17,   15,  630,   24,   25,   25,   25,   25,   22,
       24,   29,   60,   29,   24,  626,   25,   33,   33,   33,
       33,   33,   33,   36,   36,   36,   36,   47,   85,   89,
       60,  625,   87,   47,  120,   89,   36,   36,   36,   36,
       36,   37,   37,   37,   37,   87,   85,  120,   55,   55,
       55,   55,  126,   37,   37,   37,   37,   37,   37,   55,
       64,   64,   64,   64,   73,   73,   73,   73,   84,  126,
      122,  165,   84,   84,  122,   84,  158,  624,  206,   84,
      158,  165,  206,   84,   84,   37,   84,   84,   96,   96,
       96,   96,   99,   99,   99,   99,  108,  108,  108,  108,

      166,  623,  166,  108,   64,  137,  137,  137,  137,  143,
      143,  143,  143,  147,  147,  147,  147,  166,  249,  205,
      147,   73,  148,  148,  148,  148,  239,   73,  205,  249,
      239,  148,  167,  167,  167,  167,  180,  180,  180,  180,
      185,  185,  185,  185,  288,   96,   99,  622,  250,  185,
      250,   96,  186,  186,  186,  186,  189,  192,  189,  137,
      186,  189,  288,  143,  189,  331,  192,  621,  192,  331,
      192,  192,  619,  617,  192,  207,  207,  207,  207,  222,
      222,  222,  222,  224,  224,  224,  224,  222,  616,  613,
      180,  224,  223,  223,  223,  223,  612,  610,  167,  223,

      261,  261,  261,  261,  287,  608,  607,  261,  262,  262,
      262,  262,  289,  289,  289,  289,  606,  287,  293,  293,
      293,  293,  603,  321,  321,  321,  321,  322,  322,  322,
      322,  289,  354,  602,  601,  600,  354,  375,  375,  375,
      375,  207,  321,  597,  594,  592,  322,  370,  370,  370,
      370,  389,  389,  591,  375,  590,  370,  587,  382,  382,
      382,  382,  585,  392,  392,  389,  392,  391,  391,  391,
      391,  392,  414,  414,  262,  382,  391,  421,  421,  584,
      421,  583,  581,  580,  293,  421,  414,  578,  576,  575,
      574,  572,  389,  571,  570,  569,  568,  567,  566,  565,

      564,  563,  562,  561,  560,  559,  558,  557,  556,  555,
      554,  553,  548,  414,  629,  629,  629,  543,  629,  629,
      629,  631,  631,  631,  631,  631,  631,  631,  632,  632,
      542,  632,  632,  632,  632,  633,  633,  541,  633,  633,
      633,  633,  635,  635,  540,  635,  635,  635,  635,  637,
      637,  637,  637,  637,  637,  637,  638,  638,  539,  638,
      638,  639,  639,  639,  639,  639,  639,  639,  640,  640,
      537,  640,  640,  640,  640,  641,  641,  536,  535,  641,
      641,  642,  642,  534,  642,  642,  642,  642,  643,  643,
      643,  643,  643,  643,  643,  644,  644,  533,  644,  644,

      644,  644,  645,  645,  532,  645,  645,  645,  645,  646,
      646,  531,  646,  646,  646,  646,  647,  647,  529,  647,
      647,  647,  647,  648,  648,  528,  648,  648,  648,  648,
      649,  649,  527,  649,  649,  649,  649,  650,  650,  526,
      650,  650,  650,  650,  651,  651,  524,  651,  651,  651,
      651,  652,  652,  521,  652,  652,  652,  652,  653,  653,
      520,  653,  653,  653,  653,  519,  518,  515,  513,  512,
      511,  510,  508,  507,  506,  505,  504,  503,  502,  501,
      500,  499,  498,  497,  496,  495,  494,  492,  491,  490,
      489,  488,  487,  486,  485,  483,  482,  481,  480,  479,

      478,  477,  476,  475,  474,  473,  472,  471,  470,  469,
      468,  467,  466,  465,  464,  463,  462,  461,  460,  459,
      458,  457,  456,  455,  453,  452,  451,  450,  449,  448,
      447,  446,  445,  444,  443,  442,  441,  440,  439,  438,
      437,  436,  435,  434,  433,  432,  431,  430,  429,  428,
      427,  426,  425,  424,  423,  420,  419,  418,  417,  416,
      415,  413,  412,  411,  410,  409,  408,  407,  406,  405,
      404,  403,  402,  401,  400,  399,  398,  397,  396,  395,
      394,  393,  390,  388,  387,  386,  385,  384,  381,  380,
      379,  378,  376,  374,  373,  372,  371,  369,  368,  367,

      366,  365,  364,  363,  362,  361,  360,  359,  358,  356,
      355,  353,  352,  351,  349,  348,  347,  346,  345,  344,
      343,  341,  340,  339,  338,  337,  336,  335,  334,  333,
      332,  330,  329,  328,  327,  326,  325,  324,  320,  319,
      318,  317,  315,  314,  312,  311,  310,  309,  308,  307,
      306,  305,  304,  303,  302,  300,  299,  298,  297,  296,
      295,  294,  286,  285,  283,  282,  281,  280,  279,  278,
      277,  276,  275,  274,  273,  272,  271,  270,  269,  268,
      267,  266,  265,  264,  263,  258,  257,  253,  251,  248,
      247,  246,  245,  244,  243,  242,  241,  240,  238,  237,

      236,  235,  234,  233,  232,  231,  230,  229,  228,  227,
      226,  225,  220,  219,  218,  217,  215,  213,  212,  210,
      209,  208,  203,  202,  201,  200,  199,  198,  197,  196,
      195,  194,  193,  191,  190,  188,  187,  184,  183,  181,
      178,  177,  176,  175,  174,  173,  172,  171,  170,  164,
      163,  162,  161,  160,  159,  157,  156,  155,  154,  153,
      152,  151,  150,  149,  146,  145,  144,  142,  141,  140,
      139,  138,  136,  135,  134,  133,  132,  130,  128,  127,
      125,  124,  123,  121,  118,  117,  116,  115,  114,  113,
      112,  111,  110,  107,  106,  105,  104,  103,  102,  101,

      100,   98,   97,   95,   94,   93,   92,   91,   88,   83,
       82,   81,   80,   79,   78,   77,   76,   75,   74,   72,
       71,   70,   69,   68,   67,   63,   58,   57,   54,   53,
       52,   51,   50,   49,   48,   46,   45,   44,   43,   42,
       41,   40,   39,   38,   35,   30,   28,   23,   20,   19,
       18,   16,   12,    3,  628,  628,  628,  628,  628,  628,
      628,  628,  628,  628,  628,  628,  628,  628,  628,  628,
      628,  628,  628,  628,  628,  628,  628,  628,  628,  628,
      628,  628,  628,  628,  628,  628,  628,  628,  628,  628,
      628,  628,  628,  628,  628,  628,  628,  628,  628,  628,

      628,  628,  628,  628,  628,  628,  628,  628,  628,  628,
      628,  628,  628,  628,  628,  628,  628,  628,  628,  628,
      628,  628,  628,  628,  628
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[75] =
    {   0,
0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "vtkParse.l"
#line 3 "vtkParse.l"

/*

This file must be translated to C and modified to build everywhere.

Run flex like this:

  flex vtkParse.l

Modify lex.yy.c:
  - remove yyunput function
  - remove TABs

*/

/* We do not care of interactive mode */
#define YY_NEVER_INTERACTIVE 1
#define YY_NO_UNPUT 1

/* Do not include unistd.h in generated source. */
#define YY_NO_UNISTD_H

/* Skip declaring this function.  It is a macro.  */
#define YY_SKIP_YYWRAP

#ifdef _WIN32
#pragma warning ( disable : 4127 )
#pragma warning ( disable : 4131 )
#pragma warning ( disable : 4244 )
#pragma warning ( disable : 4251 )
#pragma warning ( disable : 4267 )
#pragma warning ( disable : 4305 )
#pragma warning ( disable : 4309 )
#pragma warning ( disable : 4706 )
#pragma warning ( disable : 4786 )
#endif

#line 940 "lex.yy.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO (void) fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
        if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
                { \
                int c = '*'; \
                size_t n; \
                for ( n = 0; n < max_size && \
                             (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
                        buf[n] = (char) c; \
                if ( c == '\n' ) \
                        buf[n++] = (char) c; \
                if ( c == EOF && ferror( yyin ) ) \
                        YY_FATAL_ERROR( "input in flex scanner failed" ); \
                result = n; \
                } \
        else \
                { \
                errno=0; \
                while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
                        { \
                        if( errno != EINTR) \
                                { \
                                YY_FATAL_ERROR( "input in flex scanner failed" ); \
                                break; \
                                } \
                        errno=0; \
                        clearerr(yyin); \
                        } \
                }\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
        if ( yyleng > 0 ) \
                YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
                                (yytext[yyleng - 1] == '\n'); \
        YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
        register yy_state_type yy_current_state;
        register char *yy_cp, *yy_bp;
        register int yy_act;
    
#line 43 "vtkParse.l"


#line 1097 "lex.yy.c"

        if ( (yy_init) )
                {
                (yy_init) = 0;

#ifdef YY_USER_INIT
                YY_USER_INIT;
#endif

                if ( ! (yy_start) )
                        (yy_start) = 1; /* first start state */

                if ( ! yyin )
                        yyin = stdin;

                if ( ! yyout )
                        yyout = stdout;

                if ( ! YY_CURRENT_BUFFER ) {
                        yyensure_buffer_stack ();
                        YY_CURRENT_BUFFER_LVALUE =
                                yy_create_buffer(yyin,YY_BUF_SIZE );
                }

                yy_load_buffer_state( );
                }

        while ( 1 )             /* loops until end-of-file is reached */
                {
                yy_cp = (yy_c_buf_p);

                /* Support of yytext. */
                *yy_cp = (yy_hold_char);

                /* yy_bp points to the position in yy_ch_buf of the start of
                 * the current run.
                 */
                yy_bp = yy_cp;

                yy_current_state = (yy_start);
                yy_current_state += YY_AT_BOL();
yy_match:
                do
                        {
                        register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
                        if ( yy_accept[yy_current_state] )
                                {
                                (yy_last_accepting_state) = yy_current_state;
                                (yy_last_accepting_cpos) = yy_cp;
                                }
                        while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
                                {
                                yy_current_state = (int) yy_def[yy_current_state];
                                if ( yy_current_state >= 629 )
                                        yy_c = yy_meta[(unsigned int) yy_c];
                                }
                        yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
                        ++yy_cp;
                        }
                while ( yy_base[yy_current_state] != 955 );

yy_find_action:
                yy_act = yy_accept[yy_current_state];
                if ( yy_act == 0 )
                        { /* have to back up */
                        yy_cp = (yy_last_accepting_cpos);
                        yy_current_state = (yy_last_accepting_state);
                        yy_act = yy_accept[yy_current_state];
                        }

                YY_DO_BEFORE_ACTION;

                if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
                        {
                        int yyl;
                        for ( yyl = 0; yyl < yyleng; ++yyl )
                                if ( yytext[yyl] == '\n' )
                                           
    yylineno++;
;
                        }

do_action:      /* This label is used only to access EOF actions. */

                switch ( yy_act )
        { /* beginning of action switch */
                        case 0: /* must back up */
                        /* undo the effects of YY_DO_BEFORE_ACTION */
                        *yy_cp = (yy_hold_char);
                        yy_cp = (yy_last_accepting_cpos);
                        yy_current_state = (yy_last_accepting_state);
                        goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 45 "vtkParse.l"
{ int c1 = 0, c2 = input();
       for (;;)
         {
         if (c2 == 0) 
           {
           fprintf(yyout,"Cannot find closing comment.\n");
           break;
           }
         if (c1 == '*' && c2 == '/') break;
         c1 = c2; c2 = input();
         }
     };
        YY_BREAK
case 2:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 58 "vtkParse.l"
{ 
       int c1 = 0, c2 = 0, c3 = 0, c4 = 0, c5 = input();
       for (;;)
         {
         if (c5 == 0) 
           {
           fprintf(yyout,"Cannot find matching //ETX.\n");
           break;
           }
         if (c1 == '/' && c2 == '/' && c3 == 'E' && c4 == 'T' && c5 == 'X') break;
         c1 = c2; c2 = c3; c3 = c4; c4 = c5; c5 = input();
         }
       for (;;)
         {
         if (c5 == 0) break;
         if (c5 == '\n') break;
         c5 = input();
         } 
     };
        YY_BREAK
case 3:
YY_RULE_SETUP
#line 78 "vtkParse.l"
{ 
     int pos = 1;
     while (yytext[pos-1] != 'M' || yytext[pos] != 'E')
       {
       pos++; 
       }
     yylval.str = (char *)malloc(yyleng + 1 - pos - 1);
     memcpy(yylval.str,yytext+ pos + 1,yyleng - pos - 1);
     yylval.str[yyleng - pos - 1] = '\0';
     data.NameComment = vtkstrdup(yylval.str);
     };
        YY_BREAK
case 4:
YY_RULE_SETUP
#line 90 "vtkParse.l"
{ 
     CommentState = 1;
     data.Description = (char*)malloc(100000);
     data.Description[0] = '\0';
     };
        YY_BREAK
case 5:
YY_RULE_SETUP
#line 96 "vtkParse.l"
{ 
     CommentState = 3;
     data.SeeAlso = (char*)malloc(100000);
     data.SeeAlso[0] = '\0';
     };
        YY_BREAK
case 6:
YY_RULE_SETUP
#line 102 "vtkParse.l"
{ 
     CommentState = 3;
     data.SeeAlso = (char*)malloc(100000);
     data.SeeAlso[0] = '\0';
     };
        YY_BREAK
case 7:
YY_RULE_SETUP
#line 108 "vtkParse.l"
{ 
     CommentState = 4;
     data.Caveats = (char*)malloc(100000);
     data.Caveats[0] = '\0';
     };
        YY_BREAK
case 8:
YY_RULE_SETUP
#line 114 "vtkParse.l"
{ 
     CommentState = 2;
     HaveComment = 1;
     CommentText[0] = '\0';
     };
        YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 120 "vtkParse.l"
{ 
     HaveComment = 0; 
     CommentState = 0; 
     };
        YY_BREAK
case 10:
YY_RULE_SETUP
#line 125 "vtkParse.l"
{ 
     int pos = 1;
     while (yytext[pos-1] != '/' || yytext[pos] != '/') pos++; 
     yylval.str = (char *)malloc(yyleng + 1 - pos - 1 + 1);
     memcpy(yylval.str,yytext+ pos + 1,yyleng - pos - 1);
     yylval.str[yyleng - pos - 1] = '\n';
     yylval.str[yyleng - pos] = '\0';
     switch (CommentState)
       {
       case 1: strcat(data.Description,yylval.str); break;
       case 2: strcat(CommentText,yylval.str); break;
       case 3: strcat(data.SeeAlso,yylval.str); break;
       case 4: strcat(data.Caveats,yylval.str); break;
       }
     };
        YY_BREAK
case 11:
YY_RULE_SETUP
#line 141 "vtkParse.l"
;
        YY_BREAK
case 12:
YY_RULE_SETUP
#line 143 "vtkParse.l"
;
        YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 145 "vtkParse.l"
;
        YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 147 "vtkParse.l"
{
   sscanf(yytext+1,"%d",&yylval.integer); return(ARRAY_NUM);}
        YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 151 "vtkParse.l"
return(CLASS_REF);
        YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 153 "vtkParse.l"
return(VAR_FUNCTION);
        YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 155 "vtkParse.l"
return(SHORT);
        YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 156 "vtkParse.l"
return(LONG);
        YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 157 "vtkParse.l"
return(SHORT);
        YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
#line 158 "vtkParse.l"
return(LONG);
        YY_BREAK
case 21:
YY_RULE_SETUP
#line 160 "vtkParse.l"
return(CLASS);
        YY_BREAK
case 22:
YY_RULE_SETUP
#line 161 "vtkParse.l"
return(PUBLIC);
        YY_BREAK
case 23:
YY_RULE_SETUP
#line 162 "vtkParse.l"
return(PRIVATE);
        YY_BREAK
case 24:
YY_RULE_SETUP
#line 163 "vtkParse.l"
return(PROTECTED);
        YY_BREAK
case 25:
YY_RULE_SETUP
#line 164 "vtkParse.l"
return(INT);
        YY_BREAK
case 26:
YY_RULE_SETUP
#line 165 "vtkParse.l"
return(FLOAT);
        YY_BREAK
case 27:
YY_RULE_SETUP
#line 166 "vtkParse.l"
return(SHORT);
        YY_BREAK
case 28:
YY_RULE_SETUP
#line 167 "vtkParse.l"
return(LONG);
        YY_BREAK
case 29:
YY_RULE_SETUP
#line 168 "vtkParse.l"
return(DOUBLE);
        YY_BREAK
case 30:
YY_RULE_SETUP
#line 169 "vtkParse.l"
return(VOID);
        YY_BREAK
case 31:
YY_RULE_SETUP
#line 170 "vtkParse.l"
return(CHAR);
        YY_BREAK
case 32:
YY_RULE_SETUP
#line 171 "vtkParse.l"
return(VIRTUAL);
        YY_BREAK
case 33:
YY_RULE_SETUP
#line 172 "vtkParse.l"
return(CONST);
        YY_BREAK
case 34:
YY_RULE_SETUP
#line 173 "vtkParse.l"
return(OPERATOR);
        YY_BREAK
case 35:
YY_RULE_SETUP
#line 174 "vtkParse.l"
return(UNSIGNED);
        YY_BREAK
case 36:
YY_RULE_SETUP
#line 175 "vtkParse.l"
return(FRIEND);
        YY_BREAK
case 37:
YY_RULE_SETUP
#line 176 "vtkParse.l"
return(STATIC);
        YY_BREAK
case 38:
YY_RULE_SETUP
#line 178 "vtkParse.l"
return(DOUBLE);
        YY_BREAK
case 39:
YY_RULE_SETUP
#line 179 "vtkParse.l"
return(LONG);
        YY_BREAK
case 40:
YY_RULE_SETUP
#line 180 "vtkParse.l"
return(SetMacro);
        YY_BREAK
case 41:
YY_RULE_SETUP
#line 181 "vtkParse.l"
return(GetMacro);
        YY_BREAK
case 42:
YY_RULE_SETUP
#line 182 "vtkParse.l"
return(SetStringMacro);
        YY_BREAK
case 43:
YY_RULE_SETUP
#line 183 "vtkParse.l"
return(GetStringMacro);
        YY_BREAK
case 44:
YY_RULE_SETUP
#line 184 "vtkParse.l"
return(SetClampMacro);
        YY_BREAK
case 45:
YY_RULE_SETUP
#line 185 "vtkParse.l"
return(SetObjectMacro);
        YY_BREAK
case 46:
YY_RULE_SETUP
#line 186 "vtkParse.l"
return(SetReferenceCountedObjectMacro);
        YY_BREAK
case 47:
YY_RULE_SETUP
#line 187 "vtkParse.l"
return(GetObjectMacro);
        YY_BREAK
case 48:
YY_RULE_SETUP
#line 188 "vtkParse.l"
return(BooleanMacro);
        YY_BREAK
case 49:
YY_RULE_SETUP
#line 189 "vtkParse.l"
return(SetVector2Macro);
        YY_BREAK
case 50:
YY_RULE_SETUP
#line 190 "vtkParse.l"
return(SetVector3Macro);
        YY_BREAK
case 51:
YY_RULE_SETUP
#line 191 "vtkParse.l"
return(SetVector4Macro);
        YY_BREAK
case 52:
YY_RULE_SETUP
#line 192 "vtkParse.l"
return(SetVector6Macro);
        YY_BREAK
case 53:
YY_RULE_SETUP
#line 193 "vtkParse.l"
return(GetVector2Macro);
        YY_BREAK
case 54:
YY_RULE_SETUP
#line 194 "vtkParse.l"
return(GetVector3Macro);
        YY_BREAK
case 55:
YY_RULE_SETUP
#line 195 "vtkParse.l"
return(GetVector4Macro);
        YY_BREAK
case 56:
YY_RULE_SETUP
#line 196 "vtkParse.l"
return(GetVector6Macro);
        YY_BREAK
case 57:
YY_RULE_SETUP
#line 197 "vtkParse.l"
return(SetVectorMacro);
        YY_BREAK
case 58:
YY_RULE_SETUP
#line 198 "vtkParse.l"
return(GetVectorMacro);
        YY_BREAK
case 59:
YY_RULE_SETUP
#line 199 "vtkParse.l"
return(ViewportCoordinateMacro);
        YY_BREAK
case 60:
YY_RULE_SETUP
#line 200 "vtkParse.l"
return(WorldCoordinateMacro);
        YY_BREAK
case 61:
YY_RULE_SETUP
#line 201 "vtkParse.l"
return(TypeMacro);
        YY_BREAK
case 62:
YY_RULE_SETUP
#line 202 "vtkParse.l"
return(TypeMacro);
        YY_BREAK
case 63:
YY_RULE_SETUP
#line 203 "vtkParse.l"
return(VTK_LEGACY);
        YY_BREAK
case 64:
YY_RULE_SETUP
#line 205 "vtkParse.l"
{ sscanf(yytext,"%d",&yylval.integer); return(NUM);}
        YY_BREAK
case 65:
/* rule 65 can match eol */
YY_RULE_SETUP
#line 207 "vtkParse.l"
{
                yylval.str =  vtkstrdup(yytext + 1);
                yylval.str[strlen(yytext)-2] = '\0';
                return(STRING);
                }
        YY_BREAK
case 66:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 213 "vtkParse.l"
;
        YY_BREAK
case 67:
YY_RULE_SETUP
#line 216 "vtkParse.l"
{ yylval.str = (char *)malloc(yyleng + 1);
                     memcpy(yylval.str,yytext,yyleng);
                     yylval.str[yyleng] = '\0';
                     return(VTK_ID);
                    }
        YY_BREAK
case 68:
YY_RULE_SETUP
#line 222 "vtkParse.l"
{ yylval.str = (char *)malloc(yyleng + 1);
                          memcpy(yylval.str,yytext,yyleng);
                          yylval.str[yyleng] = '\0';
                          return(ID);
                        }
        YY_BREAK
case 69:
/* rule 69 can match eol */
YY_RULE_SETUP
#line 228 "vtkParse.l"
;
        YY_BREAK
case 70:
YY_RULE_SETUP
#line 231 "vtkParse.l"
return(yytext[0]);
        YY_BREAK
case 71:
YY_RULE_SETUP
#line 232 "vtkParse.l"
return(yytext[0]);
        YY_BREAK
case 72:
YY_RULE_SETUP
#line 235 "vtkParse.l"
{       return(yytext[0]); }
        YY_BREAK
case 73:
YY_RULE_SETUP
#line 237 "vtkParse.l"
return(OTHER);
        YY_BREAK
case 74:
YY_RULE_SETUP
#line 238 "vtkParse.l"
ECHO;
        YY_BREAK
#line 1667 "lex.yy.c"
case YY_STATE_EOF(INITIAL):
        yyterminate();

        case YY_END_OF_BUFFER:
                {
                /* Amount of text matched not including the EOB char. */
                int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

                /* Undo the effects of YY_DO_BEFORE_ACTION. */
                *yy_cp = (yy_hold_char);
                YY_RESTORE_YY_MORE_OFFSET

                if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
                        {
                        /* We're scanning a new file or input source.  It's
                         * possible that this happened because the user
                         * just pointed yyin at a new source and called
                         * yylex().  If so, then we have to assure
                         * consistency between YY_CURRENT_BUFFER and our
                         * globals.  Here is the right place to do so, because
                         * this is the first action (other than possibly a
                         * back-up) that will match for the new input source.
                         */
                        (yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
                        YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
                        YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
                        }

                /* Note that here we test for yy_c_buf_p "<=" to the position
                 * of the first EOB in the buffer, since yy_c_buf_p will
                 * already have been incremented past the NUL character
                 * (since all states make transitions on EOB to the
                 * end-of-buffer state).  Contrast this with the test
                 * in input().
                 */
                if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
                        { /* This was really a NUL. */
                        yy_state_type yy_next_state;

                        (yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

                        yy_current_state = yy_get_previous_state(  );

                        /* Okay, we're now positioned to make the NUL
                         * transition.  We couldn't have
                         * yy_get_previous_state() go ahead and do it
                         * for us because it doesn't know how to deal
                         * with the possibility of jamming (and we don't
                         * want to build jamming into it because then it
                         * will run more slowly).
                         */

                        yy_next_state = yy_try_NUL_trans( yy_current_state );

                        yy_bp = (yytext_ptr) + YY_MORE_ADJ;

                        if ( yy_next_state )
                                {
                                /* Consume the NUL. */
                                yy_cp = ++(yy_c_buf_p);
                                yy_current_state = yy_next_state;
                                goto yy_match;
                                }

                        else
                                {
                                yy_cp = (yy_c_buf_p);
                                goto yy_find_action;
                                }
                        }

                else switch ( yy_get_next_buffer(  ) )
                        {
                        case EOB_ACT_END_OF_FILE:
                                {
                                (yy_did_buffer_switch_on_eof) = 0;

                                if ( yywrap( ) )
                                        {
                                        /* Note: because we've taken care in
                                         * yy_get_next_buffer() to have set up
                                         * yytext, we can now set up
                                         * yy_c_buf_p so that if some total
                                         * hoser (like flex itself) wants to
                                         * call the scanner after we return the
                                         * YY_NULL, it'll still work - another
                                         * YY_NULL will get returned.
                                         */
                                        (yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

                                        yy_act = YY_STATE_EOF(YY_START);
                                        goto do_action;
                                        }

                                else
                                        {
                                        if ( ! (yy_did_buffer_switch_on_eof) )
                                                YY_NEW_FILE;
                                        }
                                break;
                                }

                        case EOB_ACT_CONTINUE_SCAN:
                                (yy_c_buf_p) =
                                        (yytext_ptr) + yy_amount_of_matched_text;

                                yy_current_state = yy_get_previous_state(  );

                                yy_cp = (yy_c_buf_p);
                                yy_bp = (yytext_ptr) + YY_MORE_ADJ;
                                goto yy_match;

                        case EOB_ACT_LAST_MATCH:
                                (yy_c_buf_p) =
                                &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

                                yy_current_state = yy_get_previous_state(  );

                                yy_cp = (yy_c_buf_p);
                                yy_bp = (yytext_ptr) + YY_MORE_ADJ;
                                goto yy_find_action;
                        }
                break;
                }

        default:
                YY_FATAL_ERROR(
                        "fatal flex scanner internal error--no action found" );
        } /* end of action switch */
                } /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *      EOB_ACT_LAST_MATCH -
 *      EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *      EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
        register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
        register char *source = (yytext_ptr);
        register int number_to_move, i;
        int ret_val;

        if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
                YY_FATAL_ERROR(
                "fatal flex scanner internal error--end of buffer missed" );

        if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
                { /* Don't try to fill the buffer, so this is an EOF. */
                if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
                        {
                        /* We matched a single character, the EOB, so
                         * treat this as a final EOF.
                         */
                        return EOB_ACT_END_OF_FILE;
                        }

                else
                        {
                        /* We matched some text prior to the EOB, first
                         * process it.
                         */
                        return EOB_ACT_LAST_MATCH;
                        }
                }

        /* Try to read more data. */

        /* First move last chars to start of buffer. */
        number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

        for ( i = 0; i < number_to_move; ++i )
                *(dest++) = *(source++);

        if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
                /* don't do the read, it's not guaranteed to return an EOF,
                 * just force an EOF
                 */
                YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

        else
                {
                        size_t num_to_read =
                        YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

                while ( num_to_read <= 0 )
                        { /* Not enough room in the buffer - grow it. */

                        /* just a shorter name for the current buffer */
                        YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

                        int yy_c_buf_p_offset =
                                (int) ((yy_c_buf_p) - b->yy_ch_buf);

                        if ( b->yy_is_our_buffer )
                                {
                                int new_size = b->yy_buf_size * 2;

                                if ( new_size <= 0 )
                                        b->yy_buf_size += b->yy_buf_size / 8;
                                else
                                        b->yy_buf_size *= 2;

                                b->yy_ch_buf = (char *)
                                        /* Include room in for 2 EOB chars. */
                                        yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
                                }
                        else
                                /* Can't grow it, we don't own it. */
                                b->yy_ch_buf = 0;

                        if ( ! b->yy_ch_buf )
                                YY_FATAL_ERROR(
                                "fatal error - scanner input buffer overflow" );

                        (yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

                        num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
                                                number_to_move - 1;

                        }

                if ( num_to_read > YY_READ_BUF_SIZE )
                        num_to_read = YY_READ_BUF_SIZE;

                /* Read in more data. */
                YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
                        (yy_n_chars), num_to_read );

                YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
                }

        if ( (yy_n_chars) == 0 )
                {
                if ( number_to_move == YY_MORE_ADJ )
                        {
                        ret_val = EOB_ACT_END_OF_FILE;
                        yyrestart(yyin  );
                        }

                else
                        {
                        ret_val = EOB_ACT_LAST_MATCH;
                        YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
                                YY_BUFFER_EOF_PENDING;
                        }
                }

        else
                ret_val = EOB_ACT_CONTINUE_SCAN;

        (yy_n_chars) += number_to_move;
        YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
        YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

        (yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

        return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
        register yy_state_type yy_current_state;
        register char *yy_cp;
    
        yy_current_state = (yy_start);
        yy_current_state += YY_AT_BOL();

        for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
                {
                register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
                if ( yy_accept[yy_current_state] )
                        {
                        (yy_last_accepting_state) = yy_current_state;
                        (yy_last_accepting_cpos) = yy_cp;
                        }
                while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
                        {
                        yy_current_state = (int) yy_def[yy_current_state];
                        if ( yy_current_state >= 629 )
                                yy_c = yy_meta[(unsigned int) yy_c];
                        }
                yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
                }

        return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *      next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
        register int yy_is_jam;
        register char *yy_cp = (yy_c_buf_p);

        register YY_CHAR yy_c = 1;
        if ( yy_accept[yy_current_state] )
                {
                (yy_last_accepting_state) = yy_current_state;
                (yy_last_accepting_cpos) = yy_cp;
                }
        while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
                {
                yy_current_state = (int) yy_def[yy_current_state];
                if ( yy_current_state >= 629 )
                        yy_c = yy_meta[(unsigned int) yy_c];
                }
        yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
        yy_is_jam = (yy_current_state == 628);

        return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
        int c;
    
        *(yy_c_buf_p) = (yy_hold_char);

        if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
                {
                /* yy_c_buf_p now points to the character we want to return.
                 * If this occurs *before* the EOB characters, then it's a
                 * valid NUL; if not, then we've hit the end of the buffer.
                 */
                if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
                        /* This was really a NUL. */
                        *(yy_c_buf_p) = '\0';

                else
                        { /* need more input */
                        int offset = (yy_c_buf_p) - (yytext_ptr);
                        ++(yy_c_buf_p);

                        switch ( yy_get_next_buffer(  ) )
                                {
                                case EOB_ACT_LAST_MATCH:
                                        /* This happens because yy_g_n_b()
                                         * sees that we've accumulated a
                                         * token and flags that we need to
                                         * try matching the token before
                                         * proceeding.  But for input(),
                                         * there's no matching to consider.
                                         * So convert the EOB_ACT_LAST_MATCH
                                         * to EOB_ACT_END_OF_FILE.
                                         */

                                        /* Reset buffer status. */
                                        yyrestart(yyin );

                                        /*FALLTHROUGH*/

                                case EOB_ACT_END_OF_FILE:
                                        {
                                        if ( yywrap( ) )
                                                return EOF;

                                        if ( ! (yy_did_buffer_switch_on_eof) )
                                                YY_NEW_FILE;
#ifdef __cplusplus
                                        return yyinput();
#else
                                        return input();
#endif
                                        }

                                case EOB_ACT_CONTINUE_SCAN:
                                        (yy_c_buf_p) = (yytext_ptr) + offset;
                                        break;
                                }
                        }
                }

        c = *(unsigned char *) (yy_c_buf_p);    /* cast for 8-bit char's */
        *(yy_c_buf_p) = '\0';   /* preserve yytext */
        (yy_hold_char) = *++(yy_c_buf_p);

        YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');
        if ( YY_CURRENT_BUFFER_LVALUE->yy_at_bol )
                   
    yylineno++;
;

        return c;
}
#endif  /* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
        if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
                YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
        }

        yy_init_buffer(YY_CURRENT_BUFFER,input_file );
        yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
        /* TODO. We should be able to replace this entire function body
         * with
         *              yypop_buffer_state();
         *              yypush_buffer_state(new_buffer);
     */
        yyensure_buffer_stack ();
        if ( YY_CURRENT_BUFFER == new_buffer )
                return;

        if ( YY_CURRENT_BUFFER )
                {
                /* Flush out information for old buffer. */
                *(yy_c_buf_p) = (yy_hold_char);
                YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
                YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
                }

        YY_CURRENT_BUFFER_LVALUE = new_buffer;
        yy_load_buffer_state( );

        /* We don't actually know whether we did this switch during
         * EOF (yywrap()) processing, but the only time this flag
         * is looked at is after yywrap() is called, so it's safe
         * to go ahead and always set it.
         */
        (yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
        (yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
        (yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
        yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
        (yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
        YY_BUFFER_STATE b;
    
        b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
        if ( ! b )
                YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

        b->yy_buf_size = size;

        /* yy_ch_buf has to be 2 characters longer than the size given because
         * we need to put in 2 end-of-buffer characters.
         */
        b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
        if ( ! b->yy_ch_buf )
                YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

        b->yy_is_our_buffer = 1;

        yy_init_buffer(b,file );

        return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
        if ( ! b )
                return;

        if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
                YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

        if ( b->yy_is_our_buffer )
                yyfree((void *) b->yy_ch_buf  );

        yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
        int oerrno = errno;
    
        yy_flush_buffer(b );

        b->yy_input_file = file;
        b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
        errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
        if ( ! b )
                return;

        b->yy_n_chars = 0;

        /* We always need two end-of-buffer characters.  The first causes
         * a transition to the end-of-buffer state.  The second causes
         * a jam in that state.
         */
        b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
        b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

        b->yy_buf_pos = &b->yy_ch_buf[0];

        b->yy_at_bol = 1;
        b->yy_buffer_status = YY_BUFFER_NEW;

        if ( b == YY_CURRENT_BUFFER )
                yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
        if (new_buffer == NULL)
                return;

        yyensure_buffer_stack();

        /* This block is copied from yy_switch_to_buffer. */
        if ( YY_CURRENT_BUFFER )
                {
                /* Flush out information for old buffer. */
                *(yy_c_buf_p) = (yy_hold_char);
                YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
                YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
                }

        /* Only push if top exists. Otherwise, replace top. */
        if (YY_CURRENT_BUFFER)
                (yy_buffer_stack_top)++;
        YY_CURRENT_BUFFER_LVALUE = new_buffer;

        /* copied from yy_switch_to_buffer. */
        yy_load_buffer_state( );
        (yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
        if (!YY_CURRENT_BUFFER)
                return;

        yy_delete_buffer(YY_CURRENT_BUFFER );
        YY_CURRENT_BUFFER_LVALUE = NULL;
        if ((yy_buffer_stack_top) > 0)
                --(yy_buffer_stack_top);

        if (YY_CURRENT_BUFFER) {
                yy_load_buffer_state( );
                (yy_did_buffer_switch_on_eof) = 1;
        }
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
        int num_to_alloc;
    
        if (!(yy_buffer_stack)) {

                /* First allocation is just for 2 elements, since we don't know if this
                 * scanner will even need a stack. We use 2 instead of 1 to avoid an
                 * immediate realloc on the next call.
         */
                num_to_alloc = 1;
                (yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
                                                                (num_to_alloc * sizeof(struct yy_buffer_state*)
                                                                );
                
                memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
                                
                (yy_buffer_stack_max) = num_to_alloc;
                (yy_buffer_stack_top) = 0;
                return;
        }

        if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

                /* Increase the buffer to prepare for a possible push. */
                int grow_size = 8 /* arbitrary grow size */;

                num_to_alloc = (yy_buffer_stack_max) + grow_size;
                (yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
                                                                ((yy_buffer_stack),
                                                                num_to_alloc * sizeof(struct yy_buffer_state*)
                                                                );

                /* zero only the new slots.*/
                memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
                (yy_buffer_stack_max) = num_to_alloc;
        }
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
        YY_BUFFER_STATE b;
    
        if ( size < 2 ||
             base[size-2] != YY_END_OF_BUFFER_CHAR ||
             base[size-1] != YY_END_OF_BUFFER_CHAR )
                /* They forgot to leave room for the EOB's. */
                return 0;

        b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
        if ( ! b )
                YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

        b->yy_buf_size = size - 2;      /* "- 2" to take care of EOB's */
        b->yy_buf_pos = b->yy_ch_buf = base;
        b->yy_is_our_buffer = 0;
        b->yy_input_file = 0;
        b->yy_n_chars = b->yy_buf_size;
        b->yy_is_interactive = 0;
        b->yy_at_bol = 1;
        b->yy_fill_buffer = 0;
        b->yy_buffer_status = YY_BUFFER_NEW;

        yy_switch_to_buffer(b  );

        return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param str a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yy_str )
{
    
        return yy_scan_bytes(yy_str,strlen(yy_str) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * bytes, int  len )
{
        YY_BUFFER_STATE b;
        char *buf;
        yy_size_t n;
        int i;
    
        /* Get memory for full buffer, including space for trailing EOB's. */
        n = len + 2;
        buf = (char *) yyalloc(n  );
        if ( ! buf )
                YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

        for ( i = 0; i < len; ++i )
                buf[i] = bytes[i];

        buf[len] = buf[len+1] = YY_END_OF_BUFFER_CHAR;

        b = yy_scan_buffer(buf,n );
        if ( ! b )
                YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

        /* It's okay to grow etc. this buffer, and we should throw it
         * away when we're done.
         */
        b->yy_is_our_buffer = 1;

        return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
        (void) fprintf( stderr, "%s\n", msg );
        exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
        do \
                { \
                /* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
                yytext[yyleng] = (yy_hold_char); \
                (yy_c_buf_p) = yytext + yyless_macro_arg; \
                (yy_hold_char) = *(yy_c_buf_p); \
                *(yy_c_buf_p) = '\0'; \
                yyleng = yyless_macro_arg; \
                } \
        while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
        while(YY_CURRENT_BUFFER){
                yy_delete_buffer(YY_CURRENT_BUFFER  );
                YY_CURRENT_BUFFER_LVALUE = NULL;
                yypop_buffer_state();
        }

        /* Destroy the stack itself. */
        yyfree((yy_buffer_stack) );
        (yy_buffer_stack) = NULL;

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
        register int i;
        for ( i = 0; i < n; ++i )
                s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
        register int n;
        for ( n = 0; s[n]; ++n )
                ;

        return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
        return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
        /* The cast to (char *) in the following accommodates both
         * implementations that use char* generic pointers, and those
         * that use void* generic pointers.  It works with the latter
         * because both ANSI C and C++ allow castless assignment from
         * any pointer type to void*, and deal with argument conversions
         * as though doing an assignment.
         */
        return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
        free( (char *) ptr );   /* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#undef YY_NEW_FILE
#undef YY_FLUSH_BUFFER
#undef yy_set_bol
#undef yy_new_buffer
#undef yy_set_interactive
#undef yytext_ptr
#undef YY_DO_BEFORE_ACTION

#ifdef YY_DECL_IS_OURS
#undef YY_DECL_IS_OURS
#undef YY_DECL
#endif
#line 238 "vtkParse.l"
